@@ -987,6 +987,19 @@ pango_parse_stretch (const char   *str,
   return FALSE;
 }
 
+GType
+pango_matrix_get_type (void)
+{
+  static GType our_type = 0;
+  
+  if (our_type == 0)
+    our_type = g_boxed_type_register_static ("PangoMatrix",
+					     (GBoxedCopyFunc) pango_matrix_copy,
+					     (GBoxedFreeFunc) pango_matrix_free);
+
+  return our_type;
+}
+
 /**
  * pango_matrix_copy:
  * @matrix: a #PangoMatrix
@@ -997,7 +1010,7 @@ pango_parse_stretch (const char   *str,
  *  pango_matrix_free().
  **/
 PangoMatrix *
-pango_matrix_copy (PangoMatrix *matrix)
+pango_matrix_copy (const PangoMatrix *matrix)
 {
   g_return_val_if_fail (matrix != NULL, NULL);
 
@@ -1105,8 +1118,8 @@ pango_matrix_rotate (PangoMatrix *matrix,
  * given by @new_matrix then applying the original transformation.
  **/
 void
-pango_matrix_concat (PangoMatrix *matrix,
-		     PangoMatrix *new_matrix)
+pango_matrix_concat (PangoMatrix       *matrix,
+		     const PangoMatrix *new_matrix)
 {
   PangoMatrix tmp;
   
@@ -1301,7 +1314,7 @@ lang_info_compare (const void *key, const void *val)
  * in the following have sufficient text to excercise all the accents for the language, and
  * there are obviously many more languages to include as well.
  */
-static LangInfo lang_texts[] = {
+static const LangInfo lang_texts[] = {
   { "ar", "Arabic  \330\247\331\204\330\263\331\204\330\247\331\205 \330\271\331\204\331\212\331\203\331\205" },
   { "cs", "Czech (\304\215esky)  Dobr\303\275 den" },
   { "da", "Danish (Dansk)  Hej, Goddag" },
